0.3 - 2013-09-23
================

- dropped syslog-options as they are not relevant for heka-py-cef
- First official release compatible with heka 0.3


0.2 - 2012-10-01
==================

- Added syslog support for CEF mesages

0.1
==================

- initial release
